"""Steroids is a set of tools to help python developers to build cool stuff reducing efforts and time."""

__version__ = "0.12"
__author__ = "Lorenzo Setale ( http://who.is.lorenzo.setale.me/? )"
__author_email__ = "koalalorenzo@gmail.com"
__license__ = "Creative Commons Attribution-ShareAlike 3.0 Unported License http://creativecommons.org/licenses/by-nd/3.0/ "
__copyright__ = "Copyright (c) 2013, 2014 Lorenzo Setale"